<?php
/**
 *
 *User:Administrator
 *Date:2021/10/9
 */

namespace app\api\controller\v1;

use app\api\business\SuperviserTaskBus;
use app\api\business\TestUnitBus;

//监管单位
class Superviser
{

    //查找任务
    public function select()
    {
        //获取请求参数
        $data=[
            'pageNum' => request()->param('pageNum',1,'trim'),//页码
            'pageSize' => request()->param('pageSize',10,'trim'),//每页显示数量
            'task_class' => request()->param('task_class','例行监测','trim'),//任务列表：例行监测  专项监测
            'year'=>request()->param('year','','trim'),//年度
            'ispublic'=>request()->param('ispublic','','trim'),//任务状态：0：未发布，1：执行中，2：已结束未完成，3：已结束已完成
            'starttime' => request()->param('starttime','','trim'),//任务开始时间
            'endtime' => request()->param('endtime','','trim'),//任务结束时间
            'task_name' => request()->param('task_name','','trim'),//任务名称
        ];
        //todo validate

        $res= (new SuperviserTaskBus())->selectTask($data);
        return showSuccess($res);
    }

    //添加任务
    public function create()
    {
        //获取请求参数
        $data=[
            'task_name'=>request()->param('task_name','','trim'),//任务名称
            'level'=>request()->param('level','','trim'),//任务优先级，0：一般，1：紧急，2：特急
            'year'=>request()->param('year','','trim'),//年度
            'batch' => request()->param('batch', '', 'trim'),//批次，第一季度，第二季度，第三季度，第四季度
            'starttime' => request()->param('starttime','','trim'),//任务开始时间
            'endtime' => request()->param('endtime','','trim'),//任务结束时间
            'filenum' => request()->param('filenum', '', 'trim'),//文件号---选填
            'log' => request()->param('log', '', 'trim'),//备注---选填
            'file_url' => request()->param('file_url'),//附件地址
            'file_name' => request()->param('file_name', '', 'trim'),//附件名称
            'releaser' => request()->param('releaser', '', 'trim'),//发布单位//todo 固定好的，禁止修改，不需要传参
            'task_class' => request()->param('task_class', '', 'trim'),//任务类型：task_class
            'ispublic' => request()->param('ispublic', 0, 'trim'),//发布状态 
            'main_unit' => request()->param('main_unit', '', 'trim'),//牵头单位 //是orgs的name字段 二班，三班，四班，
        ];
        $orgs=request()->param('orgs', '', 'trim');

        //todo validate
        $res= (new SuperviserTaskBus())->createTask($data,$orgs);
        return showSuccess($res);
    }


    //删除任务
    public function delete()
    {
        //获取需要删除的数据的id号码
        $arr_del_task=request()->param('delarr', '', 'trim');
        $result = (new SuperviserTaskBus())->deleteTask($arr_del_task);
        return showSuccess($result);

    }

    //修改任务
    public function update()
    {
        $data = request()->param('pubarr', '', 'trim');
        $result = (new SuperviserTaskBus())->updateTask($data);
        return showSuccess($result);
    }

}